@@ -35,6 +35,7 @@ struct _DhWebViewPrivate {
         DhProfile *profile;
         gchar *search_text;
         gdouble total_scroll_delta_y;
+        WebKitUserStyleSheet *style_sheet;
 };
 
 enum {
@@ -67,6 +68,8 @@ static const guint n_zoom_levels = G_N_ELEMENTS (zoom_levels);
 
 #define ZOOM_DEFAULT (zoom_levels[2])
 
+#define DEVHELP_STYLE_SHEET     ".devhelp-hidden { display: none; }"
+
 G_DEFINE_TYPE_WITH_PRIVATE (DhWebView, dh_web_view, WEBKIT_TYPE_WEB_VIEW)
 
 static gint
@@ -469,6 +472,7 @@ dh_web_view_constructed (GObject *object)
         DhWebView *view = DH_WEB_VIEW (object);
         WebKitWebContext *webkit_context;
         WebKitSettings *webkit_settings;
+        WebKitUserContentManager *ucm;
         DhSettings *dh_settings;
 
         if (G_OBJECT_CLASS (dh_web_view_parent_class)->constructed != NULL)
@@ -484,7 +488,24 @@ dh_web_view_constructed (GObject *object)
         /* Disable some things we have no need for. */
         webkit_settings_set_enable_html5_database (webkit_settings, FALSE);
         webkit_settings_set_enable_html5_local_storage (webkit_settings, FALSE);
+#if !WEBKIT_CHECK_VERSION(2, 31, 0)
+        /* Plugins are always disabled with WebKit >= 2.32 */
         webkit_settings_set_enable_plugins (webkit_settings, FALSE);
+#endif
+
+        /* Set the User-Agent to something tools can match */
+        webkit_settings_set_user_agent_with_application_details (webkit_settings,
+                                                                 "DevHelp",
+                                                                 LIBDEVHELP_API_VERSION);
+
+        /* Inject our own style sheet */
+        view->priv->style_sheet =
+                webkit_user_style_sheet_new (DEVHELP_STYLE_SHEET,
+                                             WEBKIT_USER_CONTENT_INJECT_ALL_FRAMES,
+                                             WEBKIT_USER_STYLE_LEVEL_USER,
+                                             NULL, NULL);
+        ucm = webkit_web_view_get_user_content_manager (WEBKIT_WEB_VIEW (view));
+        webkit_user_content_manager_add_style_sheet (ucm, view->priv->style_sheet);
 
         if (view->priv->profile == NULL)
                 set_profile (view, dh_profile_get_default ());
@@ -506,6 +527,15 @@ dh_web_view_dispose (GObject *object)
 
         g_clear_object (&view->priv->profile);
 
+        if (view->priv->style_sheet != NULL) {
+                WebKitUserContentManager *ucm;
+
+                ucm = webkit_web_view_get_user_content_manager (WEBKIT_WEB_VIEW (view));
+
+                webkit_user_content_manager_remove_all_style_sheets (ucm);
+                g_clear_pointer (&view->priv->style_sheet, webkit_user_style_sheet_unref);
+        }
+
         G_OBJECT_CLASS (dh_web_view_parent_class)->dispose (object);
 }
 
